import { chromium } from 'playwright';
import isDebug from './isDebug.js';

/**
 * @param {string} url
 * @param {(page: import('playwright').Page) => Promise<any>} callback
 */
const withBrowserPage = async (url, callback) => {
  const browser = await chromium.launch({
    devtools: isDebug,
    headless: !isDebug,
  });
  const context = await browser.newContext(
    isDebug
      ? { viewport: null }
      : {
          // https://techblog.willshouse.com/2012/01/03/most-common-user-agents/
          userAgent: `Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/89.0.4389.90 Safari/537.36`,
        }
  );
  const page = await context.newPage();
  await page.goto(url);
  if (isDebug) {
    await page.$eval('body', x => {
      const script = document.createElement('script');
      script.innerHTML = `
        (async () => {
          await import('https://unpkg.com/@popperjs/core@2');
          await import('https://unpkg.com/tippy.js@6');
          tippy('[data-tippy-content]', { allowHTML: true });
        })();
      `;
      x.append(script);
      const style = document.createElement('style');
      style.innerHTML = `.catirpel-highlight {
        background-color: #ccc !important;
        border-radius: 4px !important;
        padding: 2px !important;
      }
      .catirpel-highlight.selected {
        background-color: orange !important;
      }`;
      x.append(style);
    });
  }
  await callback(page);
  if (!isDebug) {
    await context.close();
    await browser.close();
  }
};

export default withBrowserPage;
